@@ -10,6 +10,7 @@
 #include "elisaLib_export.h"
 
 #include <QObject>
+#include <QQmlEngine>
 #include <QUrl>
 #include <QMediaPlayer>
 #include <QString>
@@ -18,16 +19,12 @@
 
 class AudioWrapperPrivate;
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#define PlaybackState State
-#define playbackState state
-#endif
-
-
 class ELISALIB_EXPORT AudioWrapper : public QObject
 {
     Q_OBJECT
 
+    QML_ELEMENT
+
     Q_PROPERTY(bool muted
                READ muted
                WRITE setMuted
@@ -110,7 +107,7 @@ Q_SIGNALS:
 
     void positionChanged(qint64 position);
 
-    void currentPlayingForRadiosChanged(const QString &title, const QString &nowPlaying);
+    void currentPlayingForRadiosChanged(const QString &title, const QString &artistOrStation);
 
     void seekableChanged(bool seekable);
 
@@ -171,6 +168,10 @@ private:
 
     void playerSeekableSignalChanges(bool isSeekable);
 
+    void queueStatusChanged();
+
+    void notifyStatusChanges();
+
     friend class AudioWrapperPrivate;
 
     std::unique_ptr<AudioWrapperPrivate> d;
