@@ -642,6 +642,13 @@ void MediaPlayListProxyModel::sourceRowsInserted(const QModelIndex &parent, int
         endInsertRows();
     }
 
+    const auto url = index(mapRowFromSource(start), 0).data(MediaPlayList::ResourceRole).toUrl();
+    if (d->mTriggerPlay == ElisaUtils::TriggerPlay && url.isValid()) {
+        switchTo(mapRowFromSource(start));
+        d->mTriggerPlay = ElisaUtils::DoNotTriggerPlay;
+        Q_EMIT requestPlay();
+    }
+
     if (d->mCurrentTrack.isValid()) {
         d->mCurrentPlayListPosition = d->mCurrentTrack.row();
         determineAndNotifyPreviousAndNextTracks();
@@ -753,14 +760,16 @@ void MediaPlayListProxyModel::sourceDataChanged(const QModelIndex &topLeft, cons
     auto startSourceRow = topLeft.row();
     auto endSourceRow = bottomRight.row();
     for (int i = startSourceRow; i <= endSourceRow; i++) {
-        Q_EMIT dataChanged(index(mapRowFromSource(i), 0), index(mapRowFromSource(i), 0), roles);
+        const auto proxyRow = mapRowFromSource(i);
+
+        Q_EMIT dataChanged(index(proxyRow, 0), index(proxyRow, 0), roles);
         Q_EMIT remainingTracksDurationChanged();
         Q_EMIT totalTracksDurationChanged();
-        if (i == d->mCurrentTrack.row()) {
+        if (proxyRow == d->mCurrentTrack.row()) {
             Q_EMIT currentTrackDataChanged();
-        } else if (i == d->mNextTrack.row()) {
+        } else if (proxyRow == d->mNextTrack.row()) {
             Q_EMIT nextTrackDataChanged();
-        } else if (i == d->mPreviousTrack.row()) {
+        } else if (proxyRow == d->mPreviousTrack.row()) {
             Q_EMIT previousTrackDataChanged();
         }
         determineTracks();
